@@ -10,3 +10,6 @@ class Theme(Enum):
     BLACK_WHITE = "black_white"
     GREEN_WHITE = "green_white"
     LIGHTBLACK_WHITE = "lightblack_white"
+    DEEPGRAY_WHITE = "deepgray_white"
+    BLUE_WHITE = "blue_white"
+    PURPLE_WHITE = "purle_white"
